==> neo4j-java-driver-4.4.5-sources.jar: org/neo4j/driver/internal/util/LockUtil.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.neo4j.driver.internal.util;

import java.util.concurrent.CompletableFuture;
import java.util.concurrent.CompletionStage;
import java.util.concurrent.locks.Lock;
import java.util.function.Supplier;

public class LockUtil
{
    public static void executeWithLock( Lock lock, Runnable runnable )
    {
        lock.lock();
        try
        {
            runnable.run();
        }
        finally
        {
            lock.unlock();
        }
    }

    public static <T> T executeWithLock( Lock lock, Supplier<T> supplier )
    {
        lock.lock();
        try
        {
            return supplier.get();
        }
        finally
        {
            lock.unlock();
        }
    }

    public static <T> void executeWithLockAsync( Lock lock, Supplier<CompletionStage<T>> stageSupplier )
    {
        lock.lock();
        CompletableFuture.completedFuture( lock )
                         .thenCompose( ignored -> stageSupplier.get() )
                         .whenComplete( ( ignored, throwable ) -> lock.unlock() );
    }
}

==> neo4j-java-driver-4.4.18-sources.jar: org/neo4j/driver/internal/util/LockUtil.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.neo4j.driver.internal.util;

import java.util.concurrent.CompletableFuture;
import java.util.concurrent.CompletionStage;
import java.util.concurrent.locks.Lock;
import java.util.function.Supplier;

public class LockUtil {
    public static void executeWithLock(Lock lock, Runnable runnable) {
        lock.lock();
        try {
            runnable.run();
        } finally {
            lock.unlock();
        }
    }

    public static <T> T executeWithLock(Lock lock, Supplier<T> supplier) {
        lock.lock();
        try {
            return supplier.get();
        } finally {
            lock.unlock();
        }
    }

    public static <T> void executeWithLockAsync(Lock lock, Supplier<CompletionStage<T>> stageSupplier) {
        lock.lock();
        CompletableFuture.completedFuture(lock)
                .thenCompose(ignored -> stageSupplier.get())
                .whenComplete((ignored, throwable) -> lock.unlock());
    }
}
